Index: issm/trunk/src/m/classes/public/collapse.m
===================================================================
--- issm/trunk/src/m/classes/public/collapse.m	(revision 3759)
+++ issm/trunk/src/m/classes/public/collapse.m	(revision 3760)
@@ -19,9 +19,9 @@
 
 %drag is limited to grids that are on the bedrock.
-md.drag=project2d(md,md.drag,1);
+md.drag_coefficient=project2d(md,md.drag_coefficient,1);
 
 %p and q (same deal, except for element that are on the bedrock: )
-md.p=project2d(md,md.p,1);
-md.q=project2d(md,md.q,1);
+md.drag_p=project2d(md,md.drag_p,1);
+md.drag_q=project2d(md,md.drag_q,1);
 
 %observations
@@ -29,5 +29,5 @@
 md.vy_obs=project2d(md,md.vy_obs,md.numlayers);
 md.vel_obs=project2d(md,md.vel_obs,md.numlayers);
-md.accumulation=project2d(md,md.accumulation,md.numlayers);
+md.accumulation_rate=project2d(md,md.accumulation_rate,md.numlayers);
 md.firn_layer=project2d(md,md.firn_layer,md.numlayers);
 
@@ -70,9 +70,9 @@
 
 %materials
-md.B=DepthAverage(md,md.B);
-md.n=project2d(md,md.n,1);
+md.rheology_B=DepthAverage(md,md.rheology_B);
+md.rheology_n=project2d(md,md.rheology_n,1);
 
 %special for thermal modeling:
-md.melting=project2d(md,md.melting,1); 
+md.melting_rate=project2d(md,md.melting_rate,1); 
 md.observed_temperature=DepthAverage(md,md.observed_temperature); 
 md.geothermalflux=project2d(md,md.geothermalflux,1); %bedrock only gets geothermal flux
Index: issm/trunk/src/m/classes/public/extrude.m
===================================================================
--- issm/trunk/src/m/classes/public/extrude.m	(revision 3759)
+++ issm/trunk/src/m/classes/public/extrude.m	(revision 3760)
@@ -126,10 +126,10 @@
 %Ok, now deal with the other fields from the 2d mesh:
 
-%drag is limited to grids that are on the bedrock.
-md.drag=project3d(md,md.drag,'node',1);
+%drag_coefficient is limited to grids that are on the bedrock.
+md.drag_coefficient=project3d(md,md.drag_coefficient,'node',1);
 
 %p and q (same deal, except for element that are on the bedrock: )
-md.p=project3d(md,md.p,'element');
-md.q=project3d(md,md.q,'element');
+md.drag_p=project3d(md,md.drag_p,'element');
+md.drag_q=project3d(md,md.drag_q,'element');
 
 %observations
@@ -141,5 +141,5 @@
 md.vel_bal=project3d(md,md.vel_bal,'node');
 md.vel_obs_raw=project3d(md,md.vel_obs_raw,'node');
-md.accumulation=project3d(md,md.accumulation,'node');
+md.accumulation_rate=project3d(md,md.accumulation_rate,'node');
 md.firn_layer=project3d(md,md.firn_layer,'node',md.numlayers);
 
@@ -195,6 +195,6 @@
 
 %materials
-md.B=project3d(md,md.B,'node');
-md.n=project3d(md,md.n,'element');
+md.rheology_B=project3d(md,md.rheology_B,'node');
+md.rheology_n=project3d(md,md.rheology_n,'element');
 
 %parameters
@@ -217,5 +217,5 @@
 
 %special for thermal modeling:
-md.melting=project3d(md,md.melting,'node',1); 
+md.melting_rate=project3d(md,md.melting_rate,'node',1); 
 md.observed_temperature=project3d(md,md.observed_temperature,'node'); 
 md.geothermalflux=project3d(md,md.geothermalflux,'node',1); %bedrock only gets geothermal flux
Index: issm/trunk/src/m/classes/public/modeldefault/defaultparams.m
===================================================================
--- issm/trunk/src/m/classes/public/modeldefault/defaultparams.m	(revision 3759)
+++ issm/trunk/src/m/classes/public/modeldefault/defaultparams.m	(revision 3760)
@@ -49,15 +49,15 @@
 	%drag md.drag or stress
 	md.drag_type=2; %0 none 1 plastic 2 viscous
-	md.drag=300*ones(md.numberofgrids,1); %q=1.
+	md.drag_coefficient=300*ones(md.numberofgrids,1); %q=1.
 		
 	%zones of high md.drag
-	%[rhighmd.drag]=ArgusContourToMesh(md.elements,md.x,md.y,expread('HighDrag.exp',1),'node');
-	%pos=find(highmd.drag);md.drag(pos)=10^3;
+	%[rhighmd.drag_coefficient]=ArgusContourToMesh(md.elements,md.x,md.y,expread('HighDrag.exp',1),'node');
+	%pos=find(highmd.drag);md.drag_coefficient(pos)=10^3;
 
 	%Take care of iceshelves: no drag md.drag
 	pos=find(md.elementoniceshelf);
-	md.drag(md.elements(pos,:))=0;
-	md.p=ones(md.numberofelements,1);
-	md.q=ones(md.numberofelements,1);
+	md.drag_coefficient(md.elements(pos,:))=0;
+	md.drag_p=ones(md.numberofelements,1);
+	md.drag_q=ones(md.numberofelements,1);
 
 	%Load md.temperature from Giovinetto:
@@ -75,10 +75,10 @@
 	%flow law
 	disp('      creating flow law paramters');
-	md.n=3*ones(md.numberofelements,1);
-	md.B=paterson(md.temperature);
+	md.rheology_n=3*ones(md.numberofelements,1);
+	md.rheology_B=paterson(md.temperature);
 
 	%zones of shear margin softening
 	%[rweakb]=ArgusContourToMesh(md.elements,md.x,md.y,expread('Weakmd.BPIG.exp',1),'node');
-	%pos=find(weakb);md.B(pos)=.3*md.B(pos);
+	%pos=find(weakb);md.rheology_B(pos)=.3*md.rheology_B(pos);
 		
 	%rifts: none for now.
@@ -91,10 +91,10 @@
 
 	disp('      creating accumulation rates');
-	md.accumulation=ones(md.numberofgrids,1); %1m/a
+	md.accumulation_rate=ones(md.numberofgrids,1); %1m/a
 	
 	%Deal with boundary conditions:
 
 	disp('      thermal model');
-	md.melting=zeros(md.numberofgrids,1);
+	md.melting_rate=zeros(md.numberofgrids,1);
 	md.observed_temperature=md.temperature;
 	
@@ -49,15 +49,15 @@
 
-	%Take care of iceshelves: no drag md.drag
+	%Take care of iceshelves: no drag md.drag_coefficient
 	pos=find(md.elementoniceshelf);
